@@ -7,7 +7,7 @@ server via socket.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::MockIO> version 0.8009_1 .
+This documentation refers to C<Kafka::MockIO> version 0.8001 .
 
 =cut
 
@@ -19,7 +19,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.8009_1';
+our $VERSION = '0.8001';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -41,7 +41,6 @@ use Scalar::Util qw(
 use Sub::Install;
 
 use Kafka qw(
-    $COMPRESSION_NONE
     $ERROR_MISMATCH_ARGUMENT
     $ERROR_NO_ERROR
     $ERROR_NOT_BINARY_STRING
@@ -58,6 +57,9 @@ use Kafka::Internals qw(
     $MAX_SOCKET_REQUEST_BYTES
 );
 use Kafka::IO;
+use Kafka::Protocol qw(
+    $COMPRESSION_NONE
+);
 use Kafka::MockProtocol qw(
     decode_fetch_request
     decode_metadata_request
@@ -585,9 +587,7 @@ sub send {
     elsif ( $ApiKey == $APIKEY_METADATA ) {
         my $decoded_metadata_request = decode_metadata_request( \$message )
             or Kafka::IO::_error( $self, $ERROR_MISMATCH_ARGUMENT, $description );
-#FIXME:
-#        my $TopicName = $decoded_metadata_request->{topics}->[0];
-        my $TopicName = $decoded_metadata_request->{topics}->[0] // $TOPIC;
+        my $TopicName = $decoded_metadata_request->{topics}->[0];
         $self->_verify_string( $TopicName, "$description (TopicName)" )
             or return;
         $decoded_metadata_response->{TopicMetadata}->[0]->{TopicName} = $TopicName;
@@ -729,11 +729,6 @@ Main page at L<http://kafka.apache.org/>
 
 Kafka Protocol at L<https://cwiki.apache.org/confluence/display/KAFKA/A+Guide+To+The+Kafka+Protocol>
 
-=head1 SOURCE CODE
-
-Kafka package is hosted on GitHub:
-L<https://github.com/TrackingSoft/Kafka>
-
 =head1 AUTHOR
 
 Sergey Gladkov, E<lt>sgladkov@trackingsoft.comE<gt>
